@@ -5,7 +5,10 @@
  *                     based on work of Itai Nahshon
  * (c) 1996   jaztool  Bob Willmot (bwillmot@cnct.com)
  * (c) 1997   Mirko Kraft (Mirko.Kraft@ixos.de)
- *
+ * (cl) 1999  Aaron Segura <aaronsegura@netscape.net>
+ *      - Mutilated Code to add -ld -m -u -ud options, and
+ *        add jaz 2g Support.
+ *	  09/24/99
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -64,6 +67,10 @@
 #define SPIN_STOP			0x01
 #define SPIN_EJECT			0x02
 
+#define MOUNT_DISK			0x01 // ams
+#define UMOUNT_DISK			0x02 // ams
+#define MOUNT_CMD			"/bin/mount"
+#define UMOUNT_CMD			"/bin/umount"
 
 /*
  * Model lists. Don't delete the NULL entries. You may add new entries here,
@@ -71,7 +78,8 @@
  */
 static char	*jaz_models[] =
 {
-	"Iomega  JAZ 1GB",
+	"iomega  jaz 1gb",
+	"iomega  jaz 2gb", //ams
 	NULL
 };
 
@@ -94,7 +102,7 @@ static struct sdata
 
 static char	**model_list;
 static char	*progname;
-
+static int	mounted = 0;
 
 static int	jazip_check_dev (char*);
 static int	jazip_ctrldoor (int, int);
@@ -105,6 +113,50 @@ static int	jazip_get_mode (int);
 static int	jazip_get_password (char*, char*, int);
 static int	jazip_set_mode (int, int);
 static void	jazip_usage (char*);
+static int	jazip_ctrlmount (int, int, char *, char *);  // jazipfd, MOUNT/UMOUNT, dev, mntpoint
+
+/*
+ * Function  : jazip_ctrlmount
+ *
+ * Parameters: FD pointing to device, Operation, Device, Mountpoint
+ *
+ * Returns   : 0 on success, -1 on error
+ *
+ */
+
+jazip_ctrlmount ( int jazipfd, int oper, char *dev, char *mnt)
+{
+	int result;
+	char cmd[255];
+		
+	bzero(cmd, 255);
+
+	switch(oper)
+	{
+		case MOUNT_DISK:
+			strncpy(cmd, MOUNT_CMD, strlen(MOUNT_CMD)+1);
+			strncat(cmd, " -t ext2 ", 9 );
+			strncat(cmd, dev, strlen(dev)+1);
+			strncat(cmd, " ", 1);
+			strncat(cmd, mnt, strlen(mnt)+1);
+			break;
+		
+		case UMOUNT_DISK:	
+			jazip_ctrldoor(jazipfd, SCSI_REMOVAL_ALLOW);
+			strncpy(cmd, UMOUNT_CMD, strlen(UMOUNT_CMD)+1);
+			strncat(cmd, " ", 1);
+			strncat(cmd, dev, strnlen(dev));	
+			break;
+	}
+
+	result = system(cmd);
+	
+	if ( result == 0)
+		if ( oper == MOUNT_DISK)
+			jazip_ctrldoor(jazipfd, SCSI_REMOVAL_PREVENT);
+
+	return result;
+}
 
 
 /*
@@ -118,74 +170,33 @@ static void	jazip_usage (char*);
 static
 int	jazip_check_dev (char *dev)
 {
-	struct mntent	*mnt;
-	struct stat	st_dev, st_mnt;
 	FILE		*mtab;
+	char		mounts[255];
 	char		**model;
 	char		scsi_signature[25];
 	int		i, jazipfd;
 
-
-/*
- * Get file info and check, if we have a raw SCSI disk. Conditions:
- * -> Blockdevice
- * -> Major is SCSI_DISK_MAJOR
- * -> Minor is a multiple of 16 (or 0)
+/* 
+ * Check to see if It is mounted via /etc/mtab
+ *   (chop chop, hack hack )
+ *
  */
-	if (stat (dev, &st_dev)) {
-		(void) fprintf (stderr, "%s: stat(%s) failed: %s.\n",
-			progname, dev, strerror (errno));
-		return (-1);
+	if (! (mtab = fopen("/etc/mtab", "r") ) )
+	{
+		perror("Opening /etc/mtab");
+		exit(1);
 	}
 
-	if (!S_ISBLK (st_dev.st_mode)
-	||  MAJOR (st_dev.st_rdev) != SCSI_DISK_MAJOR
-	||  MINOR (st_dev.st_rdev) % 16 != 0) {
-		(void) fprintf (stderr, "%s: %s (%02d/%02d) is no raw scsi device.\n",
-			progname, dev, MAJOR (st_dev.st_rdev), MINOR (st_dev.st_rdev));
-		return (-1);
-	}
-
-/*
- * Now check if any partition of this device is already mounted (this
- * includes checking if the device is mounted under a different name).
- */
-	if ((mtab = setmntent (MOUNTED, "r")) == NULL) {
-		(void) fprintf (stderr, "%s: can't open %s.\n",
-			progname, MOUNTED);
-		return (-1);
-	}
-
-	while (mnt = getmntent (mtab)) {
-		if (!strcmp (mnt->mnt_type, MNTTYPE_NFS)
-		||  !strcmp (mnt->mnt_type, MNTTYPE_PROC)
-		||  !strcmp (mnt->mnt_type, MNTTYPE_AUTO)
-		||  !strcmp (mnt->mnt_type, MNTTYPE_IGNORE))
-			continue;
-
-		if (stat (mnt->mnt_fsname, &st_mnt)) {
-			(void) fprintf (stderr, "%s: stat(%s) failed: %s.\n",
-				progname, mnt->mnt_fsname, strerror (errno));
-			(void) endmntent (mtab);
-			return (-1);
-		}
-
-		if (S_ISBLK (st_mnt.st_mode)) {
-			if (MAJOR (st_mnt.st_rdev) == SCSI_DISK_MAJOR
-			&&  MINOR (st_mnt.st_rdev) >= MINOR (st_dev.st_rdev)
-			&&  MINOR (st_mnt.st_rdev) <= MINOR (st_dev.st_rdev) + 15) {
-				(void) fprintf (stderr, "%s: %s%d (%02d/%02d) is "
-					"mounted on %s.\n", progname, dev,
-					MINOR (st_mnt.st_rdev) - MINOR (st_dev.st_rdev),
-					MAJOR (st_dev.st_rdev),  MINOR (st_dev.st_rdev),
-					mnt->mnt_dir);
-				(void) endmntent (mtab);
-				return (-1);
-			}
+	while ( ! feof(mtab) )
+	{
+		fgets(mounts, 254, mtab);
+		if( strstr(mounts, dev) )
+		{
+			mounted = 1;
 		}
 	}
-
-	(void) endmntent (mtab);
+	fclose(mtab);
+	
 
 /*
  * Finally open the device and read the model signature out of it.
@@ -629,8 +640,13 @@ void 	jazip_usage (char* progname)
 		"       %s -s  <dev>   report protection status\n"
 		"       %s -ro <dev>   make disk read only\n"
 		"       %s -rp <dev>   make disk read only with password\n"
-		"       %s -rw <dev>   make disk full accessible\n\n",
-		progname, progname, progname, progname, progname);
+		"       %s -rw <dev>   make disk full accessible\n"
+		"       %s -ld <dev>   lock the door on the drive (must be mounted)\n"
+		"       %s -ud <dev>   unlock the door on the drive ^^^^^^^^^^^^^\n"
+		"       %s -m  <dev> <dir>\n"
+		"                           mounts the given <dev>4 on <dir> and locks the door\n"
+		"       %s -u  <dev>   unmounts the given <dev>4\n\n",
+		progname, progname, progname, progname, progname, progname, progname, progname, progname);
 }
 
 
@@ -646,6 +662,7 @@ void 	jazip_usage (char* progname)
 
 int	main (int argc, char *argv[])
 {
+	char	partition[10];
 	char	*ptr;
 	int	result = 1;
 	int	jazipfd;
@@ -676,19 +693,68 @@ int	main (int argc, char *argv[])
  *  -ro   Set normal write-protected mode.
  *  -rp   Set password write-protected mode.
  *  -rw   Remove any protection.
+ *  -ld   Lock the Door on a mounted Disk
+ *  -ud   Unlock the Door ....
+ *  -m    Mount and automatically Lock the Disk  Takes extra cmdline params
+ *  -u    Umount the disk. Takes extra cmdlink parameters
  */
-	if (argc == 3) {
-		if ((jazipfd = jazip_check_dev (argv[2])) >= 0) {
+	if (argc >= 3) 
+	{
+		if ((jazipfd = jazip_check_dev (argv[2])) >= 0) 
+		{
 			if (!strcmp (argv[1], "-e"))
-				result = jazip_eject (jazipfd);
+				if( ! mounted )
+					result = jazip_eject (jazipfd);
+				else 
+					printf("Device is mounted.\n");
+
 			else if (!strcmp (argv[1], "-s"))
 				result = jazip_display_mode (jazipfd);
-			else if (!strcmp (argv[1], "-ro"))
-				result = jazip_set_mode (jazipfd, IOMEGA_PROTECTION_MODE_RO);
-			else if (!strcmp (argv[1], "-rp"))
-				result = jazip_set_mode (jazipfd, IOMEGA_PROTECTION_MODE_ROPW);
-			else if (!strcmp (argv[1], "-rw"))
-				result = jazip_set_mode (jazipfd, IOMEGA_PROTECTION_MODE_RW);
+		
+			else if ( !strcmp (argv[1], "-ro"))
+				if ( ! mounted )
+					result = jazip_set_mode (jazipfd, IOMEGA_PROTECTION_MODE_RO);
+				else
+					printf("Device is mounted.\n");
+
+			else if ( !strcmp (argv[1], "-rp"))
+				if ( ! mounted )
+					result = jazip_set_mode (jazipfd, IOMEGA_PROTECTION_MODE_ROPW);
+				else
+					printf("Device is mounted.\n");
+
+			else if ( !strcmp (argv[1], "-rw")) 
+				if ( ! mounted)
+					result = jazip_set_mode (jazipfd, IOMEGA_PROTECTION_MODE_RW);
+				else
+					printf("Device is mounted.\n");
+
+			else if (!strcmp (argv[1], "-ld"))
+				if ( ! mounted)
+					printf("Device isn't mounted.\n");
+				else
+					result = jazip_ctrldoor (jazipfd, SCSI_REMOVAL_PREVENT);
+
+			else if (!strcmp (argv[1], "-ud"))
+				if ( ! mounted)
+					printf("Device isn't Locked.\n");
+				else
+					result = jazip_ctrldoor (jazipfd, SCSI_REMOVAL_ALLOW);
+
+			else if ( (!strcmp (argv[1], "-m")) && (argc == 4) )
+			{
+				strncpy(partition, argv[2], 8);
+				strncat(partition, "4", 1);
+				printf("Mounting %s on %s\n", partition, argv[3]);	
+				result = jazip_ctrlmount (jazipfd, MOUNT_DISK, partition, argv[3]);
+			}
+
+			else if ( (!strcmp (argv[1], "-u")) && (argc == 3) )
+			{	
+				strncpy(partition, argv[2], strlen(argv[2]));
+				strncat(partition, "4", 1);
+				result = jazip_ctrlmount (jazipfd, UMOUNT_DISK, partition, NULL);
+			}
 			else
 				jazip_usage (progname);
 
